@@ -86,7 +86,9 @@ class VirtualMachineInstance(NamespacedResource):
         else:
             return pods[0]
 
-        raise ResourceNotFoundError
+        raise ResourceNotFoundError(
+            f"VIRT launcher POD not found for {self.kind}:{self.name}"
+        )
 
     @property
     def virt_handler_pod(self):
@@ -115,17 +117,26 @@ class VirtualMachineInstance(NamespacedResource):
             TimeoutExpiredError: If VMI failed to run.
         """
         try:
+            self.logger.info(
+                f"VMI {self.name} status before wait: {self.instance.status.phase}"
+            )
             self.wait_for_status(
                 status=self.Status.RUNNING, timeout=timeout, stop_status=stop_status
             )
-        except TimeoutExpiredError:
+        except TimeoutExpiredError as sampler_ex:
             if not logs:
                 raise
-
-            virt_pod = self.virt_launcher_pod
-            if virt_pod:
+            self.logger.error(f"VMI {self.name} status: {self.instance.status.phase}")
+            try:
+                virt_pod = self.virt_launcher_pod
+                self.logger.error(
+                    f"Status of virt-launcher pod {virt_pod.name}: {virt_pod.status}"
+                )
                 self.logger.debug(f"{virt_pod.name} *****LOGS*****")
                 self.logger.debug(virt_pod.log(container="compute"))
+            except ResourceNotFoundError as virt_pod_ex:
+                self.logger.error(virt_pod_ex)
+                raise sampler_ex
 
             raise
 
